<?php
/* $Id: slovenian-iso-8859-2.inc.php,v 2.75 2005/07/29 17:03:22 lem9 Exp $ */

/* By: urska.colner, agenda d.o.o. <urska.colner@agenda.si>, uros kositer, agenda d.o.o. <urosh@agenda.si> */

$charset = 'iso-8859-2';
$text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = '.';
$number_decimal_separator = ',';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Ned', 'Pon', 'Tor', 'Sre', 'et', 'Pet', 'Sob');
$month = array('Jan', 'Feb', 'Mar', 'Apr', 'Maj', 'Jun', 'Jul', 'Avg', 'Sep', 'Okt', 'Nov', 'Dec');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d %B %Y ob %I:%M %p';
$timespanfmt = '%s dni, %s ur, %s minut in %s sekund';

$strAPrimaryKey = 'Na %s je dodan primarni klju';
$strAbortedClients = 'Prekinjeno';
$strAbsolutePathToDocSqlDir = 'Vnesite absolutno pot do docSQL mape na streniku';
$strAccessDenied = 'Dostop zavrnjen';
$strAccessDeniedExplanation = 'phpMyAdmin se je poskual povezati na MySQL strenik, ki je zavrnil povezavo. Preverite, ali gostitelj, uporabniko ime in geslo v datoteki config.inc.php ustrezajo podatkom administratorja MySQL strenika.';
$strAction = 'Akcija';
$strAddAutoIncrement = 'Dodaj AUTO_INCREMENT vrednost';
$strAddConstraints = 'Dodaj omejitve';
$strAddDeleteColumn = 'Dodaj/Odstrani stolpec \'Polje\'';
$strAddDeleteRow = 'Dodaj/Odstrani vrstico \'Kriterij\'';
$strAddDropDatabase = 'Dodaj DROP DATABASE';
$strAddHeaderComment = 'Dodaj prilagojen komentar v glavo (\\n prelomi vrstice)';
$strAddIfNotExists = 'Dodaj E NE OBSTAJA';
$strAddIntoComments = 'Dodaj med komentarje';
$strAddNewField = 'Dodaj novo polje';
$strAddPrivilegesOnDb = 'Dodaj privilegije na naslednji podatkovni bazi';
$strAddPrivilegesOnTbl = 'Dodaj privilegije na naslednji tabeli';
$strAddSearchConditions = 'Dodaj iskalne pogoje (telo "where" stavka):';
$strAddToIndex = 'Dodaj indeksu &nbsp;%s&nbsp;stolpec(ce)';
$strAddUser = 'Dodaj novega uporabnika';
$strAddUserMessage = 'Dodali ste novega uporabnika.';
$strAddedColumnComment = 'Dodan komentar za stolpec';
$strAddedColumnRelation = 'Dodana relacija za stolpec';
$strAdministration = 'Administracija';
$strAffectedRows = 'Spremenjene vrstice:';
$strAfter = 'Po %s';
$strAfterInsertBack = 'Nazaj na prejnjo stran';
$strAfterInsertNewInsert = 'Vstavi e eno novo vrstico';
$strAfterInsertSame = 'Pojdi nazaj na stran';
$strAll = 'Vse/Vsi';
$strAllTableSameWidth = 'prikaem vse tabele enake irine?';
$strAlterOrderBy = 'Spremeni vrstni red prikaza tabele za';
$strAnIndex = 'Na %s je dodan indeks';
$strAnalyzeTable = 'Analiziraj tabelo';
$strAnd = 'In';
$strAny = 'Katerikoli';
$strAnyHost = 'Katerikoli gostitelj';
$strAnyUser = 'Katerikoli uporabnik';
$strArabic = 'Arabsko';
$strArmenian = 'Armensko';
$strAscending = 'Naraajoe';
$strAtBeginningOfTable = 'Na zaetku tabele';
$strAtEndOfTable = 'Na koncu tabele';
$strAttr = 'Atributi';
$strAutodetect = 'Samodejno zaznaj';
$strAutomaticLayout = 'Samodejna postavitev';

$strBack = 'Nazaj';
$strBaltic = 'Baltsko';
$strBeginCut = 'ZAETEK IZREZA';
$strBeginRaw = 'BEGIN RAW';
$strBinary = 'Binarno';
$strBinaryDoNotEdit = 'Binarno - ne urejaj';
$strBookmarkAllUsers = 'Dovoli dostop do zaznamka vsem uporabnikom';
$strBookmarkDeleted = 'Zaznamek je odstranjen.';
$strBookmarkLabel = 'Nalepka';
$strBookmarkOptions = 'Monosti zaznamka';
$strBookmarkQuery = 'Oznaena SQL-poizvedba';
$strBookmarkThis = 'Oznai to SQL-poizvedbo';
$strBookmarkView = 'Samo pogled';
$strBrowse = 'Prebrskaj';
$strBrowseForeignValues = 'Prebrskaj tuje vrednosti';
$strBulgarian = 'Bolgarsko';
$strBzError = 'phpMyAdmin ni uspel stisniti odloenih podatkov zaradi neuporabne konnice Bz2 v tej razliici php. Zelo dobro bi bilo, da v konfiguracijski datoteki za phpMyAdmin spremenite ukaz <code>$cfg[\'BZipDump\']</code> v <code>FALSE</code>. e elite izvajati stiskanje s pomojo Bz2, boste morali posodobiti php v novejo razliico. Za podrobnosti si oglejte php poroilo o napaki %s.';
$strBzip = '"bzipano"';

$strCSVOptions = 'CSV monosti';
$strCalendar = 'Koledar';
$strCannotLogin = 'Ne morem se prijaviti v MySQL strenik';
$strCantLoad = 'ne morem naloiti podaljka %s,<br />prosim preverite PHP konfiguracijo';
$strCantLoadRecodeIconv = 'Ni mogoe naloiti iconv ali recode ekstenzij, ki so potrebne za pretvorbe kodnih tabel, konfigurirajte php tako, da bo omogoal uporabo teh ekstenzij ali onemogoite pretvarjanje kodnih tabel v phpMyAdmin.';
$strCantRenameIdxToPrimary = 'Indeksa ni mogoe preimenovati v PRIMARY!';
$strCantUseRecodeIconv = 'Ni mogoe uporabljati iconv, libiconv ali recode_string funkcij, eprav so ekstenzije normalno naloene. Preverite konfiguracijo php.';
$strCardinality = 'Kardinalnost';
$strCarriage = 'Znak za pomik na zaetek vrste (Carriage return): \\r';
$strCaseInsensitive = 'ne razlikuj velikih in malih rk';
$strCaseSensitive = 'razlikuj velike in male rke';
$strCentralEuropean = 'Centralno evropsko';
$strChange = 'Spremeni';
$strChangeCopyMode = 'Ustvari novega uporabnika z enakimi pravicami in ...';
$strChangeCopyModeCopy = '... obdri starega.';
$strChangeCopyModeDeleteAndReload = ' ... izbrii starega uporabnika s seznama uporabnikov ter ponovno naloi njegove pravice.';
$strChangeCopyModeJustDelete = ' ... izbrii starega s seznama uporabnikov.';
$strChangeCopyModeRevoke = ' ... preklii vse aktivne pravice starega uporabnika ter jih izbrii.';
$strChangeCopyUser = 'Spremeni prijavne informacije / Kopiraj uporabnika';
$strChangeDisplay = 'Izberite polje za prikaz';
$strChangePassword = 'Spremeni geslo';
$strCharset = 'Nabor znakov';
$strCharsetOfFile = 'Nabor znakov datoteke:';
$strCharsets = 'Nabori znakov';
$strCharsetsAndCollations = 'Nabori znakov in pravila za razvranje znakov';
$strCheckAll = 'Oznai vse';
$strCheckOverhead = 'Preveri prekoraene';
$strCheckPrivs = 'Preveri privilegije';
$strCheckPrivsLong = 'Preveri privilegije za podatkovno bazo &quot;%s&quot;.';
$strCheckTable = 'Preveri tabelo';
$strChoosePage = 'Izberite stran za urejanje';
$strColComFeat = 'Prikazovanje komentarjev stolpcev';
$strCollation = 'Pravilo za razvranje znakov';
$strColumnNames = 'Imena stolpcev';
$strColumnPrivileges = 'Privilegiji tipini za stolpec';
$strCommand = 'Ukaz';
$strComments = 'Komentarji';
$strCommentsForTable = 'KOMENTARJI ZA TABELO';
$strCompleteInserts = 'Popolne \'insert\' poizvedbe';
$strCompression = 'Stiskanje';
$strConfigFileError = 'phpMyAdmin ni mogel prebrati konfiguracijske datoteke!<br />To se lahko zgodi, e php pri prevajanju konfiguracijske datoteke najde napako ali pa ne najde datoteke.<br />Prosimo, odprite konfiguracijsko datoteko s povezavo, ki je navedena spodaj in preberite dobljeno sporoilo o napaki. V veini primerov gre za manjkajoi narekovaj ali podpije.<br />e dobite prazno stran, je vse v redu.';
$strConfigureTableCoord = 'Prosimo, konfigurirajte koordinate za tabelo %s';
$strConnectionError = 'Povezava ni mogoa: neveljavne nastavitve.';
$strConnections = 'Povezave';
$strConstraintsForDumped = 'Omejitve tabel za povzetek stanja';
$strConstraintsForTable = 'Omejitve za tabelo';
$strCookiesRequired = 'e elite e dalje uporabljati program, morate omogoiti pikotke.';
$strCopyTable = 'Kopiraj tabelo v (podatkovna_baza<b>.</b>tabela):';
$strCopyTableOK = 'Tabela %s je skopirana v %s.';
$strCopyTableSameNames = 'Tabele ni mogoe kopirati same vase!';
$strCouldNotKill = 'phpMyAdmin ni uspel prekiniti teme %s. Verjetno je e prekinjena.';
$strCreate = 'Ustvari';
$strCreateIndex = 'Ustvari indeks na&nbsp;%s&nbsp;stolpcih';
$strCreateIndexTopic = 'Ustvari nov indeks';
$strCreateNewDatabase = 'Ustvari novo podatkovno bazo';
$strCreateNewTable = 'Ustvari novo tabelo v podatkovni bazi %s';
$strCreatePage = 'Ustvari novo stran';
$strCreatePdfFeat = 'Ustvarjanje PDF datotek';
$strCreationDates = 'Datumi za ustvarjeno/posodobljeno/preverjeno';
$strCriteria = 'Kriteriji';
$strCroatian = 'Hrvako';
$strCyrillic = 'Cirilica';
$strCzech = 'eko';
$strCzechSlovak = 'ekoslovako';

$strDBComment = 'Komentar zbirke podatkov: ';
$strDBGContext = 'Kontekst';
$strDBGContextID = 'Kontekst ID';
$strDBGHits = 'Zadetki';
$strDBGLine = 'Vrstica';
$strDBGMaxTimeMs = 'Najveji as, ms';
$strDBGMinTimeMs = 'Najmanji as, ms';
$strDBGModule = 'Modul';
$strDBGTimePerHitMs = 'as/Zadetek, ms';
$strDBGTotalTimeMs = 'Skupni as, ms';
$strDBRename = 'Preimenuj podatkovno bazo v';
$strDanish = 'Dansko';
$strData = 'Podatki';
$strDataDict = 'Podatkovni slovar';
$strDataOnly = 'Samo podatki';
$strDatabase = 'Podatkovna baza';
$strDatabaseEmpty = 'Ime podatkovne baze je prazno!';
$strDatabaseExportOptions = 'Monosti za izvoz baze podatkov';
$strDatabaseHasBeenDropped = 'Podatkovna baza %s je zavrena.';
$strDatabaseNoTable = 'Ta baza podatkov ne vsebuje tabele!!';
$strDatabases = 'podatkovne baze';
$strDatabasesDropped = '%s podatkovne baze so uspeno zavrene.';
$strDatabasesStats = 'Statistika podatkovnih baz';
$strDatabasesStatsDisable = 'Onemogoi statistiko';
$strDatabasesStatsEnable = 'Omogoi statistiko';
$strDatabasesStatsHeavyTraffic = 'Obvestilo: Omogoitev statistike podatkovne baze lahko povzroi mono povean promet med spletnim in podatkovnim strenikom.';
$strDbPrivileges = 'Privilegiji tipini za podatkovno bazo';
$strDbSpecific = 'glede na zbirko podatkov';
$strDefault = 'Privzeto';
$strDefaultValueHelp = 'Za privzete vrednosti vnesite samo vrednosti, brez poevnice nazaj ali narekovaja, npr.: a';
$strDelOld = 'Trenutna stran vsebuje sklice na tabele, ki ne obstajajo ve. Ali elite izbrisati te sklice?';
$strDelayedInserts = 'Uporabi zakasnjeno vstavljanje';
$strDelete = 'Izbrii';
$strDeleteAndFlush = 'Izbrii uporabnike in potem osvei privilegije.';
$strDeleteAndFlushDescr = 'To je najbolji nain, vendar lahko osveevanje privilegijev traja nekaj asa.';
$strDeleted = 'Vrstica je izbrisana';
$strDeletedRows = 'Izbrisane vrstice:';
$strDeleting = 'Briem %s';
$strDescending = 'Padajoe';
$strDescription = 'Opis';
$strDictionary = 'slovar';
$strDisabled = 'Onemogoeno';
$strDisplayFeat = 'Prikai lastnosti';
$strDisplayOrder = 'Vrstni red prikaza:';
$strDisplayPDF = 'Prikai PDF shemo';
$strDoAQuery = 'Izvedi "query by example" (nadomestni znak: "%")';
$strDoYouReally = 'Ali res elite ';
$strDocu = 'Dokumentacija';
$strDrop = 'Zavri';
$strDropDatabaseStrongWarning = 'S tem dejanjem boste UNIILI celotno bazo podatkov!';
$strDropSelectedDatabases = 'Zavri izbrane podatkovne baze';
$strDropUsersDb = 'Izbrii podatkovne baze, ki imajo enako ime kot uporabniki.';
$strDumpSaved = 'Dump je shranjen v datoteko %s.';
$strDumpXRows = 'Odloi %s vrstic, zani z zapisom # %s.';
$strDumpingData = 'Odloi podatke za tabelo';
$strDynamic = 'dinamino';

$strEdit = 'Uredi';
$strEditPDFPages = 'Uredi PDF strani';
$strEditPrivileges = 'Uredi privilegije';
$strEffective = 'Uinkovito';
$strEmpty = 'Izprazni';
$strEmptyResultSet = 'MySQL je vrnil kot rezultat prazno mnoico (npr. ni vrstic).';
$strEnabled = 'Omogoeno';
$strEncloseInTransaction = 'Vkljui izvoz v transakcijo';
$strEnd = 'Konec';
$strEndCut = 'KONEC IZREZA';
$strEndRaw = 'END RAW';
$strEnglish = 'Angleko';
$strEnglishPrivileges = ' Opomba: Imena MySQL privilegijev so zapisana v angleini ';
$strError = 'Napaka';
$strEstonian = 'Estonsko';
$strExcelEdition = 'Izdaja za Excel';
$strExcelOptions = 'Monosti za Excel';
$strExecuteBookmarked = 'Izvedi izbrano poizvedbo';
$strExplain = 'Razloi SQL stavek';
$strExport = 'Izvozi';
$strExtendedInserts = 'Razirjene \'insert\' poizvedbe';
$strExtra = 'Dodatno';

$strFailedAttempts = 'Neuspeli poizkusi';
$strField = 'Polje';
$strFieldHasBeenDropped = 'Polje %s je zavreno';
$strFields = 'Polja';
$strFieldsEmpty = ' tevec polj je prazen! ';
$strFieldsEnclosedBy = 'Polja obdana z';
$strFieldsEscapedBy = 'Polja izognjena z';
$strFieldsTerminatedBy = 'Polja zakljuena z';
$strFileAlreadyExists = 'Datoteka %s e obstaja na streniku, spremenite ime novi ali prepiite obstojeo datoteko.';
$strFileCouldNotBeRead = 'Ne morem prebrati datoteke';
$strFileNameTemplate = 'Predloga datoteke';
$strFileNameTemplateHelp = 'Uporabi __DB__ za ime zbirke podatkov, __TABLE__ za ime tabele in monosti %sany strftime%s za navedbo asa, pripone pa bodo dodane samodejno. Ostalo besedilo ostane nespremenjeno.';
$strFileNameTemplateRemember = 'Shrani predlogo';
$strFixed = 'fiksno';
$strFlushPrivilegesNote = 'Obvestilo: phpMyAdmin dobi podatke o uporabnikovih privilegijih iz MySQL tabel privilegijev. Vsebina teh tabel se lahko razlikuje od privilegijev, ki jih uporablja strenik, e so bile tabele rono spremenjene. V tem primeru morate, preden nadaljujete, osveiti privilegije.';
$strFlushTable = 'Poisti tabelo ("FLUSH")';
$strFormEmpty = 'V obliki manjka vrednost !';
$strFormat = 'Oblika';
$strFullText = 'Polna besedila';
$strFunction = 'Funkcija';

$strGenBy = 'Ustvaril';
$strGenTime = 'as nastanka';
$strGeneralRelationFeat = 'Splone lastnosti relacij';
$strGeorgian = 'Gruzijsko';
$strGerman = 'Nemko';
$strGlobal = 'globalno';
$strGlobalPrivileges = 'Globalni privilegiji';
$strGlobalValue = 'Skupna vrednost';
$strGo = 'Izvedi';
$strGrantOption = 'Dovoli';
$strGreek = 'Grko';
$strGzip = '"gzipano"';

$strHasBeenAltered = 'je bil spremenjen(a).';
$strHasBeenCreated = 'je bil ustvarjen(a).';
$strHaveToShow = 'Za prikaz morate izbrati morate vsaj en stolpec';
$strHebrew = 'Hebrejsko';
$strHome = 'Domov';
$strHomepageOfficial = 'Uradna domaa stran phpMyAdmin';
$strHost = 'Gostitelj';
$strHostEmpty = 'Ime gostitelja je prazno!';
$strHungarian = 'Madarsko';

$strId = 'ID';
$strIdxFulltext = 'Polno besedilo';
$strIfYouWish = 'e bi radi naloili samo nekatere stolpce tabele, jih navedite v seznamu, kjer jih loite z vejico.';
$strIgnore = 'Prezri';
$strIgnoreInserts = 'Uporabi monost prezri vstavke';
$strIgnoringFile = 'Prezrl sem datoteko %s';
$strImportDocSQL = 'Uvozi docSQL datoteke';
$strImportFiles = 'Uvozi datoteke';
$strImportFinished = 'Uvoz konan';
$strInUse = 'v uporabi';
$strIndex = 'Indeks';
$strIndexHasBeenDropped = 'Indeks %s je zavren';
$strIndexName = 'Ime indeksa&nbsp;:';
$strIndexType = 'Vrsta indeksa&nbsp;:';
$strIndexes = 'Indeksi';
$strInnodbStat = 'InnoDB stanje';
$strInsecureMySQL = 'Konfiguracijska datoteka vsebuje nastavitve (uporabnik root brez gesla), ki odgovarjajo privzetemu privlegiranemu raunu MySQLa. MySQL strenik tee s privzetimi nastavitvami, zato je izpostavljen vdorom. imprej odpravite ti dve varnostni luknji.';
$strInsert = 'Vstavi';
$strInsertAsNewRow = 'Vstavi kot novo vrstico';
$strInsertNewRow = 'Vstavi novo vrstico';
$strInsertTextfiles = 'V tabelo vstavi podatke iz datoteke z besedilom';
$strInsertedRowId = 'Vstavljen id vrstice:';
$strInsertedRows = 'Vstavljene vrstice:';
$strInstructions = 'Navodila';
$strInternalNotNecessary = '* Notranja relacija je nepotrebna, e obstaja tudi v InnoDB.';
$strInternalRelations = 'Notranje relacije';

$strJapanese = 'Japonsko';
$strJumpToDB = 'Preskoi na podatkovno bazo &quot;%s&quot;.';
$strJustDelete = 'Samo izbrii uporabnike iz tabel privilegijev.';
$strJustDeleteDescr = '&quot;Izbrisani&quot; uporabniki lahko e vedno normalno dostopajo do strenika, dokler ne osveite privilegijev';

$strKeepPass = 'Ne spreminjaj gesla';
$strKeyname = 'Ime kljua';
$strKill = 'Prekini proces';
$strKorean = 'Korejsko';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'Monosti za LaTeX';
$strLandscape = 'Leee';
$strLatexCaption = 'Ime tabele';
$strLatexContent = 'Vsebina tabele __TABLE__';
$strLatexContinued = '(nadaljevanje)';
$strLatexContinuedCaption = 'Nadaljevanje imena tabele';
$strLatexIncludeCaption = 'Vkljui ime tabele';
$strLatexLabel = 'Oznai klju';
$strLatexStructure = 'Struktura tabele __TABLE__';
$strLengthSet = 'Dolina/Vrednosti*';
$strLimitNumRows = 'tevilo vrstic na stran';
$strLineFeed = 'Pomik v novo vrsto (Linefeed): \\n';
$strLinesTerminatedBy = 'Vrstice zakljuene z';
$strLinkNotFound = 'Povezave ni mogoe najti';
$strLinksTo = 'Povezave z';
$strLithuanian = 'Litvansko';
$strLoadExplanation = 'Privzeto je izbrana najbolja metoda, ki pa jo lahko v primeru neuspeha zamenjate.';
$strLoadMethod = 'LOAD metoda';
$strLocalhost = 'Lokalno';
$strLocationTextfile = 'Lokacija datoteke z besedilom';
$strLogPassword = 'Geslo:';
$strLogServer = 'Strenik';
$strLogUsername = 'Uporabniko ime:';
$strLogin = 'Prijava';
$strLoginInformation = 'Podatki o prijavi';
$strLogout = 'Odjava';

$strMIMETypesForTable = 'VRSTE MIME ZA TABELO';
$strMIME_MIMEtype = 'MIME-vrsta';
$strMIME_available_mime = 'Razpololjive MIME-vrste';
$strMIME_available_transform = 'Razpololjive pretvorbe';
$strMIME_description = 'Opis';
$strMIME_nodescription = 'Za to pretvorbo ni na voljo opisa.<br />Za funkcije %s se pozanimajte pri avtorju.';
$strMIME_transformation = 'Pretvorba z brskalnikom';
$strMIME_transformation_note = 'Seznam razpololjivih monosti pretvorbe in pretvorbe MIME-vrst boste videli, e kliknete na %sopise transformacij%s';
$strMIME_transformation_options = 'Monosti pretvorbe';
$strMIME_transformation_options_note = 'Vrednosti za monosti pretvorbe vnesite v naslednji obliki: \'a\',\'b\',\'c\'...<br />e elite med vrednosti vnesti poevnico nazaj ("\") ali enojni narekovaj ("\'"), morate pred ta znak postaviti (e eno) poevnico nazaj (npr. \'\\\\xyz\' ali \'a\\\'b\').';
$strMIME_without = 'MIME-vrste, ki so napisano leee, nimajo lastne pretvorbene funkcije';
$strMaximumSize = 'Najveja velikost: %s%s';
$strModifications = 'Spremembe so shranjene';
$strModify = 'Spremeni';
$strModifyIndexTopic = 'Spremeni indeks';
$strMoreStatusVars = 'Dodatne statusne spremenljivke';
$strMoveTable = 'Premakni tabelo v (podatkovna_baza<b>.</b>tabela):';
$strMoveTableOK = 'Tabela %s je bila premaknjena v %s.';
$strMoveTableSameNames = 'Tabele ni mogoe premakniti same vase!';
$strMultilingual = 'vejezino';
$strMustSelectFile = 'Izberite datoteko, ki jo elite vstaviti.';
$strMySQLCharset = 'MySQL kodna tabela';
$strMySQLReloaded = 'MySQL ponovno naloen.';
$strMySQLSaid = 'MySQL je vrnil: ';
$strMySQLServerProcess = 'MySQL %pma_s1% tee na %pma_s2% kot %pma_s3%';
$strMySQLShowProcess = 'Pokai procese';
$strMySQLShowStatus = 'Pokai tekoe informacije o MySQL';
$strMySQLShowVars = 'Pokai sistemske spremenljivke MySQL';

$strName = 'Ime';
$strNeedPrimaryKey = 'Doloite primarni klju za to tabelo.';
$strNext = 'Naslednji';
$strNo = 'Ne';
$strNoDatabases = 'Brez podatkovnih baz';
$strNoDatabasesSelected = 'Ni izbranih podatkovnih baz.';
$strNoDescription = 'brez opisa';
$strNoDropDatabases = '"DROP DATABASE" poizvedbe so izkljuene.';
$strNoExplain = 'Preskoi razlago SQL stavka';
$strNoFrames = 'phpMyAdmin je prijazneji z brskalnikom, ki podpira okvirje.';
$strNoIndex = 'Ni definiranega indeksa!';
$strNoIndexPartsDefined = 'Ni definiranega dela indeksa!';
$strNoModification = 'Brez sprememb';
$strNoOptions = 'Za to obliko ni monosti';
$strNoPassword = 'Brez gesla';
$strNoPermission = 'Spletni strenik nima dovoljenja za shranjevanje datoteke %s';
$strNoPhp = 'Brez kode PHP';
$strNoPrivileges = 'Brez privilegijev';
$strNoQuery = 'Brez SQL poizvedbe!';
$strNoRights = 'Nimate dovolj pravic, da bi bili sedaj tukaj!';
$strNoSpace = 'Ni dovolj prostora za shranjevanje datoteke %s.';
$strNoTablesFound = 'V podatkovni bazi ni mogoe najti tabel.';
$strNoUsersFound = 'Ni mogoe najti uporabnika(ov).';
$strNoValidateSQL = 'Preskoi preverjanje pravilnosti SQL stavka';
$strNone = 'Brez';
$strNotNumber = 'To ni tevilo!';
$strNotOK = 'Ni v redu';
$strNotSet = 'Tabele <b>%s</b> ni mogoe najti ali pa ni v %s';
$strNull = 'Null';
$strNumSearchResultsInTable = '%s zadetek(ov) v tabeli <i>%s</i>';
$strNumSearchResultsTotal = '<b>Skupaj:</b> <i>%s</i> zadetek(ov)';
$strNumTables = 'Ttabel';

$strOK = 'V redu';
$strOftenQuotation = 'Pogosti narekovaji. OPCIJSKO pomeni, da so samo polja tipa \'char\' in \'varchar\' obdana s temi znaki.';
$strOperations = 'Operacije';
$strOperator = 'Operator';
$strOptimizeTable = 'Optimiraj tabelo';
$strOptionalControls = 'Opcijsko. Narekuje nain pisanja in branja posebnih znakov.';
$strOptionally = 'OPCIJSKO';
$strOr = 'Ali';
$strOverhead = 'Preseek';
$strOverwriteExisting = 'Prepii obstojeo(e) datoteko(e)';

$strPHP40203 = 'Uporabljate PHP 4.2.3, ki ima resne teave z vebitnimi stavki (mbstring). Glej PHP poroilo o hrou 19404. Ta verzija PHP ni priporoljiva za uporabo s phpMyAdmin.';
$strPHPVersion = 'Razliica PHP';
$strPageNumber = 'tevilka strani:';
$strPaperSize = 'Velikost papirja';
$strPartialText = 'Delna besedila';
$strPassword = 'Geslo';
$strPasswordChanged = 'Geslo za %s je uspeno spremenjeno.';
$strPasswordEmpty = 'Geslo je prazno!';
$strPasswordNotSame = 'Gesli se ne ujemata!';
$strPdfDbSchema = 'Shema podatkovne baze "%s" - Stran %s';
$strPdfInvalidTblName = 'Tabela "%s" ne obstaja!';
$strPdfNoTables = 'Ni tabel';
$strPerHour = 'na uro';
$strPerMinute = 'na minuto';
$strPerSecond = 'na sekundo';
$strPhoneBook = 'telefonski imenik';
$strPhp = 'Ustvari PHP kodo';
$strPmaDocumentation = 'phpMyAdmin dokumentacija';
$strPmaUriError = 'Ukaz <tt>$cfg[\'PmaAbsoluteUri\']</tt> mora biti definiran v konfiguracijski datoteki!';
$strPortrait = 'Pokonno';
$strPos1 = 'Zaetek';
$strPrevious = 'Prejnji';
$strPrimary = 'Primarni';
$strPrimaryKeyHasBeenDropped = 'Primarni klju je zavren';
$strPrimaryKeyName = 'Ime primarnega kljua mora biti... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>mora</b> biti ime <b>samo</b> primarnega kljua!)';
$strPrint = 'Natisni';
$strPrintView = 'Pogled postavitve tiskanja';
$strPrintViewFull = 'Pogled za tiskanje (s polnimi besedili)';
$strPrivDescAllPrivileges = 'Vsebuje vse privilegije razen GRANT.';
$strPrivDescAlter = 'Omogoa spreminjanje strukture obstojeih tabel.';
$strPrivDescCreateDb = 'Omogoa ustvarjanje novih podatkovnih baz in tabel.';
$strPrivDescCreateTbl = 'Omogoa ustvarjanje novih tabel.';
$strPrivDescCreateTmpTable = 'Omogoa ustvarjanje zaasnih tabel.';
$strPrivDescDelete = 'Omogoa brisanje podatkov.';
$strPrivDescDropDb = 'Omogoa brisanje podatkovnih baz in tabel.';
$strPrivDescDropTbl = 'Omogoa brisanje tabel.';
$strPrivDescExecute = 'Omogoa poganjanje shranjenih postopkov; V tej verziji MySQL nima pomena.';
$strPrivDescFile = 'Omogoa uvaanje in izvaanje podatkov v datoteke.';
$strPrivDescGrant = 'Omogoa dodajanje uporabnikov in privilegijev brez osveevanja privilegijev.';
$strPrivDescIndex = 'Omogoa ustvarjanje in brisanje indeksov.';
$strPrivDescInsert = 'Omogoa vstavljanje in zamenjavo podatkov.';
$strPrivDescLockTables = 'Omogoa zaklepanje tabel za trenutno temo.';
$strPrivDescMaxConnections = 'Omeji tevilo povezav, ki jih uporabnik lahko odpre v eni uri.';
$strPrivDescMaxQuestions = 'Omeji tevilo poizved, ki jih uporabnik lahko polje streniku v eni uri.';
$strPrivDescMaxUpdates = 'Omeji tevilo ukazov za spremembo tabel ali podatkovne baze, ki jih uporabnik lahko izvri v eni uri.';
$strPrivDescProcess3 = 'Omogoa ukinjanje procesov drugih uporabnikov.';
$strPrivDescProcess4 = 'Omogoa pregled popolnih poizvedb v spisku procesov.';
$strPrivDescReferences = 'V tej verziji MySQL nima pomena.';
$strPrivDescReload = 'Omogoa osveevanje strenikovih nastavitev in praznjenje strenikovih predpomnilnikov.';
$strPrivDescReplClient = 'Da uporabniku pravico poizvedovati kje so njegovi nadrejeni / podrjeni streniki.';
$strPrivDescReplSlave = 'Potrebno za podrejene strenike pri replikaciji.';
$strPrivDescSelect = 'Omogoa branje podatkov.';
$strPrivDescShowDb = 'Omogoa dostop do popolnega spiska podatkovnih baz';
$strPrivDescShutdown = 'Omogoa ugaanje strenika.';
$strPrivDescSuper = 'Omogoa priklaplanje tudi e je e doseeno najveje dovoljeno tevilo priklopov; Potrebno za veino administrativnih nalog kot sta postavljanje globalnih spremenljivk in ukinjanje procesov drugih uporabnikov.';
$strPrivDescUpdate = 'Omogoa spreminjanje podatkov.';
$strPrivDescUsage = 'Brez privilegijev.';
$strPrivileges = 'Privilegiji';
$strPrivilegesReloaded = 'Uspeno sem osveil privilegije.';
$strProcesslist = 'Seznam procesov';
$strPutColNames = 'Postavi imena polj v prvo vrstico';

$strQBE = 'Poizvedba';
$strQBEDel = 'Brii';
$strQBEIns = 'Vstavi';
$strQueryFrame = 'Okno za iskanje';
$strQueryOnDb = 'SQL-poizvedba na podatkovni bazi <b>%s</b>:';
$strQuerySQLHistory = 'SQL-zgodovina';
$strQueryStatistics = '<b>Statistika poizvedbe</b>: Od zagona je bilo streniku poslanih %s poizvedb.';
$strQueryTime = 'Poizvedba je potrebovala %01.4f s';
$strQueryType = 'Vrsta poizvedbe';
$strQueryWindowLock = 'Ne prepii te poizvedbe od zunaj';

$strReType = 'Ponovno vnesi';
$strReceived = 'Prejeto';
$strRecords = 'Zapisi';
$strReferentialIntegrity = 'Preveri referenno integriteto:';
$strRelationNotWorking = 'Dodatne funkcije za delo s povezanimi tabelami so bile izkjuene. e elite izvedeti zakaj, kliknite %stukaj%s.';
$strRelationView = 'Pogled relacij';
$strRelationalSchema = 'Relacijska shema';
$strRelations = 'Relacije';
$strRelationsForTable = 'RELACIJE ZA TABELO';
$strReloadFailed = 'Ponovno nalaganje MySQL ni uspelo.';
$strReloadMySQL = 'Ponovno naloi MySQL';
$strReloadingThePrivileges = 'Osveujem privilegije';
$strRemoveSelectedUsers = 'Izbrii izbrane uporabnike';
$strRenameDatabaseOK = 'Baza podatkov %s je preimenovana v %s';
$strRenameTable = 'Preimenuj tabelo v';
$strRenameTableOK = 'Tabela %s je preimenovana v %s';
$strRepairTable = 'Popravi tabelo';
$strReplace = 'Zamenjaj';
$strReplaceNULLBy = 'Zamenjaj NULL z';
$strReplaceTable = 'Podatke v tabeli zamenjaj z datoteko';
$strReset = 'Ponastavi';
$strResourceLimits = 'Omejitve virov';
$strRevoke = 'Odvzemi';
$strRevokeAndDelete = 'Odvzemi uporabnikom aktivne privilegije in jih potem izbrii.';
$strRevokeAndDeleteDescr = 'Uporabniki bodo e vedno imeli USAGE privilegije, dokler ne osveite privilegijev.';
$strRevokeMessage = 'Odvzeli ste privilegije za %s';
$strRowLength = 'Dolina vrstice';
$strRowSize = ' Velikost vrstice ';
$strRows = 'Vrstice';
$strRowsFrom = 'vrstice naprej od zapisa #';
$strRowsModeFlippedHorizontal = 'vodoravno (zasukani naslovi)';
$strRowsModeHorizontal = 'vodoravnem';
$strRowsModeOptions = 'v %s nainu in ponovi glavo po %s celicah';
$strRowsModeVertical = 'navpinem';
$strRowsStatistic = 'Statistika vrstic';
$strRunQuery = 'Izvedi poizvedbo';
$strRunSQLQuery = 'Izvedi SQL poizvedbo/poizvedbe na podatkovni bazi %s';
$strRunning = 'tee na %s';
$strRussian = 'Rusko';

$strSQL = 'SQL';
$strSQLExportType = 'Vrsta izvoza';
$strSQLOptions = 'SQL monosti';
$strSQLParserBugMessage = 'Obstaja monost, da ste v SQL razlenjevalniku naleteli na hroa. Temeljito preglejte poizvedbo in preverite, e so citati pravilni in e se ujemajo. Mono je tudi, da prenaate binarno datoteko, ki je izven podroja besedila citata. Poizvedbo lahko preizkusite tudi na vmesniku ukazne vrstice MySQL. e je strenik MySQL izpisal napako, vam le-ta lahko pomaga pri ugotavljanju teav. e se bodo teave nadaljevale, ali e razlenjevalniku ne uspe tam, kjer vmesniku ukazne vrstice uspe, potem zmanjajte vneeno SQL poizvedbo na tisto poizvedbo, ki povzroa teave in poljite poroilo o napaki skupaj s podatki iz spodnjega odseka IZREZA.';
$strSQLParserUserError = 'Izgleda, da je v SQL poizvedbi prilo do napake. e je strenik MySQL izpisal napako, vam le-ta lahko pomaga pri ugotavljanju teav.';
$strSQLQuery = 'SQL-poizvedba';
$strSQLResult = 'Rezultat SQL';
$strSQPBugInvalidIdentifer = 'Neveljavni identifikator';
$strSQPBugUnclosedQuote = 'Odprt citat';
$strSQPBugUnknownPunctuation = 'Neznan niz loil';
$strSave = 'Shrani';
$strSaveOnServer = 'Shrani na strenik, v imenik %s';
$strScaleFactorSmall = 'Faktor poveava je premajhen, da bi spravili shemo na eno stran';
$strSearch = 'Iskanje';
$strSearchFormTitle = 'Ii v podatkovni bazi';
$strSearchInTables = 'V tabelah:';
$strSearchNeedle = 'Iskane besede ali vrednosti (nadomestni znak: "%"):';
$strSearchOption1 = 'katerokoli besedo';
$strSearchOption2 = 'vse besede';
$strSearchOption3 = 'tono doloeno frazo';
$strSearchOption4 = 'kot \'regular expression\'';
$strSearchResultsFor = 'Rezultati iskanja "<i>%s</i>" %s:';
$strSearchType = 'Najdi:';
$strSecretRequired = 'Konfiguracijski datoteki morate sedaj doloiti skrivno geslo (blowfish_secret).';
$strSelectADb = 'Prosimo, izberite podatkovno bazo';
$strSelectAll = 'Izberi vse';
$strSelectFields = 'Izberite polja (vsaj eno):';
$strSelectNumRows = 'in poizvedba';
$strSelectTables = 'Izberi tabele';
$strSend = 'Shrani kot datoteko';
$strSent = 'Poslano';
$strServer = 'Strenik';
$strServerChoice = 'Izbira strenika';
$strServerStatus = 'Podatki o izvajanju';
$strServerStatusUptime = 'MySQL strenik deluje e %s. Zagnal se je %s.';
$strServerTabProcesslist = 'Procesi';
$strServerTabVariables = 'Spremenljivke';
$strServerTrafficNotes = '<b>Promet na streniku</b>: V teh tabelah je prikazana statistika obremenitve omreja za ta MySQL strenik, odkar je bil zagnan.';
$strServerVars = 'Spremenljivke in nastavitve strenika';
$strServerVersion = 'Razliica strenika';
$strSessionValue = 'Vrednost seje';
$strSetEnumVal = 'e je polje vrste "enum" ali "set", navedite vrednosti v obliki: \'a\',\'b\',\'c\'...<br /> e elite med vrednostmi uporabiti poevnico ("\") ali enojni narekovaj ("\'"), pred tem znakom vnesite poevnico (n.pr. \'\\\\xyz\' ali \'a\\\'b\').';
$strShow = 'Pokai';
$strShowAll = 'Pokai vse';
$strShowColor = 'Pokai barvo';
$strShowDatadictAs = 'Oblika podatkovnega slovarja';
$strShowFullQueries = 'Pokai celotne poizvedbe';
$strShowGrid = 'Pokai mreo';
$strShowPHPInfo = 'Pokai podatke o PHP';
$strShowTableDimension = 'Pokai dimenzije tabel';
$strShowTables = 'Pokai tabele';
$strShowThisQuery = ' Ponovno pokai poizvedbo v tem oknu ';
$strShowingRecords = 'Prikazujem vrstice';
$strSimplifiedChinese = 'Poenostavljeno kitajsko';
$strSingly = '(posamezno)';
$strSize = 'Velikost';
$strSort = 'Sortiraj';
$strSortByKey = 'Uredi po kljuu';
$strSpaceUsage = 'Poraba prostora';
$strSplitWordsWithSpace = 'Besede so loene s presledkom (" ").';
$strStatCheckTime = 'Zadnji pregledano';
$strStatCreateTime = 'Ustvarjeno';
$strStatUpdateTime = 'Zadnji posodobljeno';
$strStatement = 'Izjave';
$strStatus = 'Stanje';
$strStrucCSV = 'CSV podatki';
$strStrucData = 'Struktura in podatki';
$strStrucDrop = 'Dodaj DROP TABLE poizvedbo';
$strStrucExcelCSV = 'CSV podatki za MS Excel';
$strStrucOnly = 'Samo struktura';
$strStructPropose = 'Predlagaj strukturo tabele';
$strStructure = 'Struktura';
$strSubmit = 'Polji';
$strSuccess = 'SQL-poizvedba je bila uspeno izvedena';
$strSum = 'Vsota';
$strSwedish = 'vedsko';
$strSwitchToTable = 'Preklopi na kopirano tabelo';

$strTable = 'Tabela';
$strTableComments = 'Komentar tabele';
$strTableEmpty = 'Ime tabele je prazno!';
$strTableHasBeenDropped = 'Tabela %s je zavrena';
$strTableHasBeenEmptied = 'Tabela %s je izpraznjena';
$strTableHasBeenFlushed = 'Tabela %s je osveena';
$strTableMaintenance = 'Vzdrevanje tabele';
$strTableOfContents = 'Vsebina';
$strTableOptions = 'Monosti tabele';
$strTableStructure = 'Struktura tabele';
$strTableType = 'Vrsta tabele';
$strTables = '%s tabel';
$strTblPrivileges = 'Privilegiji tipini za tabelo';
$strTextAreaLength = ' Zaradi njegove doline<br /> polja ne bo mogoe urejati ';
$strThai = 'Tajsko';
$strTheContent = 'Vsebina datoteke je vneena.';
$strTheContents = 'Vsebina datoteke zamenja vsebino izbrane tabele v vrsticah z identinim primarnim ali unikatnim kljuem.';
$strTheTerminator = 'Zakljuni znak polj.';
$strThisHost = 'Ta strenik';
$strThisNotDirectory = 'To ni bila mapa';
$strThreadSuccessfullyKilled = 'Tema %s je bila prekinjena.';
$strTime = 'as';
$strToggleScratchboard = 'preklopi odloie (scratchboard)';
$strTotal = 'skupaj';
$strTotalUC = 'Skupaj';
$strTraditionalChinese = 'Tradicionalno kitajsko';
$strTraffic = 'Promet';
$strTransformation_application_octetstream__download = 'Prikai povezavo za prenos binarnih podatkov polja. Prva monost je ime binarne datoteke. Druga monost je mono ime polja v vrstici tabele, ki vsebuje to ime datoteke. e vnesete drugo monost, mora biti prva monost prazna';
$strTransformation_image_jpeg__inline = 'Prikae sliico, na katero lahko kliknete; monosti: irina, viina v slikovnih pikah (obdri prvotna razmerja)';
$strTransformation_image_jpeg__link = 'Pokae povezavo na grafiko (neposredni BLOB prenos, ipd.).';
$strTransformation_image_png__inline = 'Pokai sliko/jpeg: vkljueno';
$strTransformation_text_plain__dateformat = 'Oblikuje polje TIME, TIMESTAMP ali DATETIME glede na lokalne oblike za prikaz asa. Prva monost je odmik (v urah), ki bo dodan polju timestamp (Privzeto: 0). Druga monost je drugana oblika prikaza datuma, glede na parametre za PHP strftime().';
$strTransformation_text_plain__external = 'SAMO ZA LINUX: Zaene zunanjo aplikacijo in podaja podatke za fielddata preko standardnega vhoda. Vrne standardni izhod aplikacije. Privzeto je Tidy, za tiskanje HTML-kode. Zaradi varnostnih razlogov morate rono urediti datoteko libraries/transformations/text_plain__external.inc.php in vstaviti orodja za zaganjanje. Prva monost je tevilka programa, ki ga elite uporabiti, druga monost pa so parametri za program. e tretji parameter nastavite na 1, bo s pomojo htmlspecialchars() pretvoril izhod (Privzeto: 1). e nastavite etrti parameter na 1, bo v celico z vsebino (content cell) vnesel NOWRAP in tako prikazal celoten izhod brez preoblikovanja (Privzeto: 1)';
$strTransformation_text_plain__formatted = 'Ohrani izvirno oblikovanje polja, brez izgubljanja vsebine.';
$strTransformation_text_plain__imagelink = 'Prikae sliko in povezavo, polje vsebuje ime datoteke; najprej je predpona, npr. "http://domena.com/", druga monost je irina v slikovnih pikah, tretja pa viina.';
$strTransformation_text_plain__link = 'Prikae povezavo, polje vsebuje ime datoteke; prva monost je predpona, npr. "http://domena.com/", druga pa ime povezave.';
$strTransformation_text_plain__substr = 'Vrne le del niza. Prva monost je odmik, ki doloa, kje se bo zaelo prikazano besedilo (Privzeto: 0). Druga monost je odmik, ki pove, koliko besedila bo prikazanega. e ni doloen, bo izpisano vse preostalo besedilo. Tretja monost pa doloa, kateri znaki bodo pripeti vrnjenemu podnizu (Privzeto: ...) .';
$strTruncateQueries = 'Skri prikazane poizvedbe';
$strTurkish = 'Turko';
$strType = 'Vrsta';

$strUkrainian = 'Ukrajinsko';
$strUncheckAll = 'Odznai vse';
$strUnicode = 'Unicode';
$strUnique = 'Unikaten';
$strUnknown = 'neznano';
$strUnselectAll = 'Preklii izbor vsega';
$strUpdComTab = 'Navodila za posodobitev tabele Column_comments\' najdete v dokumentaciji';
$strUpdatePrivMessage = 'Posodobili ste privilegije za %s.';
$strUpdateProfileMessage = 'Profil je posodobljen.';
$strUpdateQuery = 'Osvei poizvedbo';
$strUpgrade = '%s bi morali nadgraditi v verzijo %s ali novejo.';
$strUsage = 'Uporaba';
$strUseBackquotes = 'Obdaj imena tabel in polj z enojnimi poevnimi narekovaji';
$strUseHostTable = 'Uporabi tabelo gostiteljev';
$strUseTables = 'Uporabi tabele';
$strUseTextField = 'Uporabi tekstovno polje';
$strUseThisValue = 'Uporabi to vrednost';
$strUser = 'Uporabnik';
$strUserAlreadyExists = 'Uporabnik %s e obstaja!';
$strUserEmpty = 'Uporabniko ime je prazno!';
$strUserName = 'Uporabniko ime';
$strUserNotFound = 'Izbranega uporabnika v tabelah privilegijev nisem nael.';
$strUserOverview = 'Pregled uporabnikov';
$strUsersDeleted = 'Uspeno sem izbrisal izbrane uporabnike.';
$strUsersHavingAccessToDb = 'Uporabniki dostop do &quot;%s&quot;';

$strValidateSQL = 'Preveri pravilnost SQL stavka';
$strValidatorError = 'Ne morem inicializirati SQL validatorja. Prosim preverite, e so nameeni vsi php raziritve, kot je navedeno v %dokumenaciji%.';
$strValue = 'Vrednost';
$strVar = 'Spremenljivka';
$strViewDump = 'Preglej povzetek stanja tabele';
$strViewDumpDB = 'Preglej povzetek stanja podatkovne baze';
$strViewDumpDatabases = 'Pokai povzetek stanja podatkovnih baz';

$strWebServerUploadDirectory = 'imenik za nalaganje datotek';
$strWebServerUploadDirectoryError = 'Imenik, ki ste ga doloili za nalaganje, je nedosegljiv';
$strWelcome = 'Dobrodoli v %s';
$strWestEuropean = 'Zahodno evropsko';
$strWildcard = 'nadomestni znak';
$strWindowNotFound = 'Ciljnega okna ni bilo mogoe osveiti. Morda ste zaprli nadrejeno okno ali pa va brskalnik blokira osveevanje varnostnih parametrov med okni.';
$strWithChecked = 'Z oznaenim:';
$strWritingCommentNotPossible = 'Zapisovanje komentarjev ni mogoe';
$strWritingRelationNotPossible = 'Zapisovanje relacij ni mogoe';
$strWrongUser = 'Napano uporabniko ime/geslo. Dostop zavrnjen.';

$strXML = 'XML';

$strYes = 'Da';

$strZeroRemovesTheLimit = 'Obvestilo: e postavite vrednost na 0 (ni), boste odstranili omejitev.';
$strZip = '"zipano"';

$strRefresh = 'Refresh';  //to translate
$strDefragment = 'Defragment table';  //to translate
$strNoRowsSelected = 'No rows selected';  //to translate
$strSpanish = 'Spanish';  //to translate
$strStrucNativeExcel = 'Native MS Excel data';  //to translate
$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
$strServerNotResponding = 'The server is not responding';  //to translate
$strTheme = 'Theme / Style';  //to translate
$strTakeIt = 'take it';  //to translate
$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
$strIcelandic = 'Icelandic';  //to translate
$strLatvian = 'Latvian';  //to translate
$strPolish = 'Polish';  //to translate
$strRomanian = 'Romanian';  //to translate
$strSlovenian = 'Slovenian';  //to translate
$strTraditionalSpanish = 'Traditional Spanish';  //to translate
$strSlovak = 'Slovak';  //to translate
$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
$strPersian = 'Persian';  //to translate
$strAddFields = 'Add %s field(s)';  //to translate
$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strRoutines = 'Routines';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strAndThen = 'and then';  //to translate
?>
